@@ -12,7 +12,7 @@ plot.confint.glht <- function(x, ...) {
          type = "n", axes = FALSE, xlab = "", ylab = "", xlim = xrange, ...)
     axis(1, ...)
     axis(2, at = nrow(xi):1, labels = dimnames(xi)[[1]], 
-         srt = 0, ...)
+         las = 1, ...)
     abline(h = yvals, lty = 1, lwd = 0, col = "lightgray")
     abline(v = 0, lty = 2, lwd = 0, ...)
     left <- xi[, "lwr"]
